@@ -279,6 +279,7 @@ class SmappeeLocalMqtt(threading.Thread):
                 self._timezone = c.get('timeZone')
                 self._service_location_id = c.get('serviceLocationId')
                 self._service_location_uuid = c.get('serviceLocationUuid')
+                self._serial_number = c.get('serialNumber')
             elif message.topic.endswith('channelConfig'):
                 pass
             elif message.topic.endswith('/channelConfigV2'):
@@ -311,11 +312,12 @@ class SmappeeLocalMqtt(threading.Thread):
                 # switches
                 switches = json.loads(message.payload).get('switchActuators', [])
                 for switch in switches:
-                    self.switch_sensors.append({
-                        'nodeId': switch['nodeId'],
-                        'name': switch['name'],
-                        'serialNumber': switch['serialNumber']
-                    })
+                    if switch['serialNumber'].startswith('4006'):
+                        self.switch_sensors.append({
+                            'nodeId': switch['nodeId'],
+                            'name': switch['name'],
+                            'serialNumber': switch['serialNumber']
+                        })
 
                 # plugs
                 plugs = json.loads(message.payload).get('smartplugActuators', [])
@@ -383,11 +385,15 @@ class SmappeeLocalMqtt(threading.Thread):
     def is_config_ready(self, timeout=60, interval=5):
         c = 0
         while c < timeout:
-            if self.phase_type is not None:
-                break
+            if self.phase_type is not None and self._serial_number is not None:
+                return self._serial_number
             c += interval
             time.sleep(interval)
 
+    def start_and_wait_for_config(self):
+        self.start()
+        return self.is_config_ready()
+
     def start_attempt(self):
         client = mqtt.Client(client_id='smappeeLocalMqttConnectionAttempt')
         try:
